@@ -1,5 +1,5 @@
 from fakts.discovery.base import Discovery
-from fakts.discovery.endpoint import FaktsEndpoint
+from fakts.discovery.base import FaktsEndpoint
 
 
 class StaticDiscovery(Discovery):
@@ -7,3 +7,6 @@ class StaticDiscovery(Discovery):
 
     async def discover(self):
         return FaktsEndpoint(base_url=self.base_url)
+
+    class Config:
+        extra = "forbid"
