@@ -3,9 +3,9 @@ import yaml
 
 
 class YamlGrant(FaktsGrant):
-    filepath: str = "random.yaml"
+    filepath: str
 
-    async def aload(self, previous={}, **kwargs):
+    async def aload(self, force_refresh=False, **kwargs):
         with open(self.filepath, "r") as file:
             config = yaml.load(file, Loader=yaml.FullLoader)
 
